package net.sf.logdistiller;

/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.regex.Pattern;

/**
 * @since 1.1
 */
public class Attributes
    implements Serializable
{
    private static final long serialVersionUID = -3748978489200255819L;

    public static final Extension[] NO_EXTENSIONS = new Extension[0];

    private final String attributes;

    private final Extension[] extensions;

    public Attributes( String attributes, Extension[] extensions )
    {
        this.attributes = attributes;
        this.extensions = extensions;
    }

    public int getExtensionsCount()
    {
        return extensions.length;
    }

    public Extension[] getExtensions()
    {
        return extensions;
    }

    public String getAttributes()
    {
        return attributes;
    }

    public static class Extension
        implements Serializable
    {
        private static final long serialVersionUID = 4511835440598290789L;

        private final String source;

        private final List/*<String>*/ provides;

        private transient final Pattern regexp;

        public Extension( String source, String provides, String regexp )
        {
            this.source = source;
            String[] attributes = provides.split( "," );
            this.provides = new ArrayList( attributes.length );
            for ( int i = 0; i < attributes.length; i++ )
            {
                String attribute = attributes[i].trim();
                this.provides.add( attribute );
            }
            this.regexp = Pattern.compile( regexp );
        }

        public String getSource()
        {
            return source;
        }

        public List getProvides()
        {
            return provides;
        }

        public Pattern getRegexp()
        {
            return regexp;
        }
    }
}
