package net.sf.logdistiller;

/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.io.IOException;

/**
 * Base class of report publishers, for both global and group reports.
 */
public abstract class Publisher
{
    /**
     * Get the publisher-id for this class.
     *
     * @return a unique publisher id
     */
    public abstract String getId();

    /**
     * Publish a global report.
     *
     * @param logdistillation the logdistillation containing the results to publish
     * @param report the report configuration
     * @throws IOException
     * @throws PublishException
     */
    public abstract void publish( LogDistillation logdistillation, LogDistiller.Report report )
        throws IOException, PublishException;

    /**
     * Publish a group report.
     *
     * @param group the logdstillation group containing the results to publish
     * @param report the report configuration
     * @throws IOException
     * @throws PublishException
     */
    public abstract void publish( LogDistillation.Group group, LogDistiller.Report report )
        throws IOException, PublishException;

    public static class PublishException
        extends Exception
    {
        private static final long serialVersionUID = 498326805296616769L;

        public PublishException( String message, Throwable nested )
        {
            super( message, nested );
        }
    }
}
