package net.sf.logdistiller.ant;

/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import org.apache.tools.ant.Project;
import org.apache.tools.ant.types.Path;
import org.apache.tools.ant.types.Reference;

/**
 * Definition of logevent class in Ant buildfile.
 *
 * <pre>
 * &lt;logevent factory=&quot;&lt;i&gt;[event factory class]&lt;/i&gt;&quot;/&gt;
 * </pre>
 */
public class AntLogEvent
{
    private final Project project;

    private String logtype;

    private Path classpath;

    public AntLogEvent( Project project )
    {
        this.project = project;
    }

    public void setClasspath( Path classpath )
    {
        if ( this.classpath == null )
        {
            this.classpath = classpath;
        }
        else
        {
            this.classpath.append( classpath );
        }
    }

    public Path createClasspath()
    {
        if ( classpath == null )
        {
            classpath = new Path( project );
        }
        return classpath.createPath();
    }

    public void setClasspathRef( Reference r )
    {
        createClasspath().setRefid( r );
    }

    public void setLoaderRef( Reference r )
    {
    }

    /**
     * @deprecated replaced by <code>logtype</code> attribute
     */
    public void setFactory( String factory )
    {
        setLogtype( factory );
        project.log( "WARNING: attribute 'factory' is deprecated, please use attribute 'logtype' instead",
                     Project.MSG_WARN );
    }

    public void setLogtype( String logtype )
    {
        this.logtype = logtype;
    }

    public String getLogtype()
    {
        return logtype;
    }
}
