package net.sf.logdistiller.gui;

/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.lang.reflect.*;
import java.awt.event.ItemListener;
import java.awt.event.ItemEvent;

public class SwingAdapter
{
    private SwingAdapter()
    {
    }

    public static ActionListener getActionListener( Object obj, String methodName )
    {
        try
        {
            Class[] paramTypes = { ActionEvent.class };
            Method method = obj.getClass().getMethod( methodName, paramTypes );
            return new ActionAdapter( obj, method );
        }
        catch ( NoSuchMethodException nsme )
        {
            throw new RuntimeException( "method 'public void " + methodName + "(ActionEvent ae)' not found in "
                + obj.getClass().getName(), nsme );
        }
    }

    public static Runnable getRunnable( Object obj, String methodName )
    {
        try
        {
            Class[] paramTypes = {};
            Method method = obj.getClass().getMethod( methodName, paramTypes );
            return new RunnableAdapter( obj, method );
        }
        catch ( NoSuchMethodException nsme )
        {
            throw new RuntimeException( "method 'public void " + methodName + "()' not found in "
                + obj.getClass().getName(), nsme );
        }
    }

    public static ItemListener getItemListener( Object obj, String methodName )
    {
        try
        {
            Class[] paramTypes = { ItemEvent.class };
            Method method = obj.getClass().getMethod( methodName, paramTypes );
            return new ItemAdapter( obj, method );
        }
        catch ( NoSuchMethodException nsme )
        {
            throw new RuntimeException( "method 'public void " + methodName + "(ItemEvent ie)' not found in "
                + obj.getClass().getName(), nsme );
        }
    }

    private static class ActionAdapter
        implements ActionListener
    {
        private final Object target;

        private final Method method;

        public ActionAdapter( Object target, Method method )
        {
            this.target = target;
            this.method = method;
        }

        public void actionPerformed( ActionEvent ae )
        {
            try
            {
                method.invoke( target, new Object[] { ae } );
            }
            catch ( InvocationTargetException ite )
            {
                throw new RunException( ite );
            }
            catch ( IllegalArgumentException iae )
            {
                throw new RuntimeException( "IllegalArgumentException invoking method '" + method.getName() + "'", iae );
            }
            catch ( IllegalAccessException iae )
            {
                throw new RuntimeException( "IllegalAccessException invoking method '" + method.getName() + "'", iae );
            }
        }
    }

    private static class RunnableAdapter
        implements Runnable
    {
        private final Object target;

        private final Method method;

        public RunnableAdapter( Object target, Method method )
        {
            this.target = target;
            this.method = method;
        }

        public void run()
        {
            try
            {
                method.invoke( target, new Object[] {} );
            }
            catch ( InvocationTargetException ite )
            {
                throw new RunException( ite );
            }
            catch ( IllegalArgumentException iae )
            {
                throw new RuntimeException( "IllegalArgumentException invoking method '" + method.getName() + "'", iae );
            }
            catch ( IllegalAccessException iae )
            {
                throw new RuntimeException( "IllegalAccessException invoking method '" + method.getName() + "'", iae );
            }
        }
    }

    private static class ItemAdapter
        implements ItemListener
    {
        private final Object target;

        private final Method method;

        public ItemAdapter( Object target, Method method )
        {
            this.target = target;
            this.method = method;
        }

        public void itemStateChanged( ItemEvent ie )
        {
            try
            {
                method.invoke( target, new Object[] { ie } );
            }
            catch ( InvocationTargetException ite )
            {
                throw new RunException( ite );
            }
            catch ( IllegalArgumentException iae )
            {
                throw new RuntimeException( "IllegalArgumentException invoking method '" + method.getName() + "'", iae );
            }
            catch ( IllegalAccessException iae )
            {
                throw new RuntimeException( "IllegalAccessException invoking method '" + method.getName() + "'", iae );
            }
        }
    }

    public static class RunException
        extends RuntimeException
    {
        private static final long serialVersionUID = 4688792600015649872L;

        private RunException( Exception nestedException )
        {
            super( nestedException );
        }
    }
}
