package net.sf.logdistiller.publishers;

/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.util.*;

import net.sf.logdistiller.*;

/**
 * Declaration of base publishers that are shipped with <b>LogDistiller</b>.
 *
 * @since 0.7
 */
public class BasePublishers
    extends Publishers
{
    // feed publisher has a dependency on Rome, which must really stay optional (should have been an extension)
    private final static Publisher FEED_PUBLISHER =
        new DelegatePublisher( "feed", BasePublishers.class.getPackage().getName() + ".FeedPublisher" );

    private final static Publisher[] REPORT_TYPES = { new FilePublisher(), new MailPublisher(), FEED_PUBLISHER };

    private final static List REPORT_TYPES_LIST = Collections.unmodifiableList( Arrays.asList( REPORT_TYPES ) );

    public List definePublishers()
    {
        return REPORT_TYPES_LIST;
    }
}
