package net.sf.logdistiller.xml;

/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.io.InputStream;
import java.util.HashSet;
import java.util.Set;
import org.xml.sax.EntityResolver;
import org.xml.sax.InputSource;

public class LogDistillerEntityResolver
    implements EntityResolver
{
    public final static String LATEST_DTD = "logdistiller-1_4.dtd";

    public final static String LATEST_DTD_URL = "http://logdistiller.sourceforge.net/dtd/" + LATEST_DTD;

    private final static Set DTDS = new HashSet()
    {
        {
            add( "logdistiller-1_0.dtd" );
            add( "logdistiller-1_1.dtd" );
            add( "logdistiller-1_2.dtd" );
            add( "logdistiller-1_3.dtd" );
            add( "logdistiller-1_4.dtd" );
        }
    };

    private final static int LEN = 20; // length of dtd string...

    private String currentDtd;

    public InputSource resolveEntity( String publicId, String systemId )
    {
        if ( systemId.length() < LEN )
        {
            return null;
        }
        String dtd = systemId.substring( systemId.length() - LEN );
        if ( DTDS.contains( dtd ) )
        {
            currentDtd = dtd;
            InputStream in = LogDistillerEntityResolver.class.getResourceAsStream( dtd );
            if ( in == null )
            {
                throw new RuntimeException( "unable to load DTD " + dtd );
            }
            else
            {
                return new InputSource( in );
            }
        }
        else
        {
            return null;
        }
    }

    public String getCurrentDtd()
    {
        return currentDtd;
    }
}
